# SysInfo

Simple Linux command for newbies made by dawidePl.

## Table of contents

* [General Info](#general-info)
* [Setup](#setup)
* [Notes](#notes)

## General Info

SysInfo is Linux command providing informations about hardware usage. Data is shown in simple form, so that non-technical users can fully and easily understand it.

## Setup

Coming in next version.

## Notes

To use this command, you need to have Python with any version below `3.8` ( Python `3.8` and further removed necessary stuff )